@@ -1,3 +1,5 @@
+// +build darwin
+
 package gateway
 
 import (
@@ -5,7 +7,7 @@ import (
 	"os/exec"
 )
 
-func DiscoverGateway() (net.IP, error) {
+func discoverGatewayOSSpecific() (net.IP, error) {
 	routeCmd := exec.Command("/sbin/route", "-n", "get", "0.0.0.0")
 	output, err := routeCmd.CombinedOutput()
 	if err != nil {
@@ -14,3 +16,7 @@ func DiscoverGateway() (net.IP, error) {
 
 	return parseDarwinRouteGet(output)
 }
+
+func discoverGatewayInterfaceOSSpecific() (ip net.IP, err error) {
+	return nil, errNotImplemented
+}
