@@ -11,8 +11,13 @@ type testcase struct {
 	gateway string
 }
 
-func TestParseWindowsRoutePrint(t *testing.T) {
+func TestParseWindows(t *testing.T) {
 	correctData := []byte(`
+===========================================================================
+Interface List
+  8 ...00 12 3f a7 17 ba ...... Intel(R) PRO/100 VE Network Connection
+  1 ........................... Software Loopback Interface 1
+===========================================================================
 IPv4 Route Table
 ===========================================================================
 Active Routes:
@@ -20,6 +25,21 @@ Network Destination        Netmask          Gateway       Interface  Metric
           0.0.0.0          0.0.0.0       10.88.88.2     10.88.88.149     10
 ===========================================================================
 Persistent Routes:
+`)
+	localizedData := []byte(
+		`===========================================================================
+Liste d'Interfaces
+ 17...00 28 f8 39 61 6b ......Microsoft Wi-Fi Direct Virtual Adapter
+  1...........................Software Loopback Interface 1
+===========================================================================
+IPv4 Table de routage
+===========================================================================
+Itinéraires actifs :
+Destination réseau    Masque réseau  Adr. passerelle   Adr. interface Métrique
+          0.0.0.0          0.0.0.0      10.88.88.2     10.88.88.149     10
+===========================================================================
+Itinéraires persistants :
+  Aucun
 `)
 	randomData := []byte(`
 Lorem ipsum dolor sit amet, consectetur adipiscing elit,
@@ -27,11 +47,21 @@ sed do eiusmod tempor incididunt ut labore et dolore magna
 aliqua. Ut enim ad minim veniam, quis nostrud exercitation
 `)
 	noRoute := []byte(`
+===========================================================================
+Interface List
+  8 ...00 12 3f a7 17 ba ...... Intel(R) PRO/100 VE Network Connection
+  1 ........................... Software Loopback Interface 1
+===========================================================================
 IPv4 Route Table
 ===========================================================================
 Active Routes:
 `)
 	badRoute1 := []byte(`
+===========================================================================
+Interface List
+  8 ...00 12 3f a7 17 ba ...... Intel(R) PRO/100 VE Network Connection
+  1 ........................... Software Loopback Interface 1
+===========================================================================
 IPv4 Route Table
 ===========================================================================
 Active Routes:
@@ -39,6 +69,11 @@ Active Routes:
 Persistent Routes:
 `)
 	badRoute2 := []byte(`
+===========================================================================
+Interface List
+  8 ...00 12 3f a7 17 ba ...... Intel(R) PRO/100 VE Network Connection
+  1 ........................... Software Loopback Interface 1
+===========================================================================
 IPv4 Route Table
 ===========================================================================
 Active Routes:
@@ -50,117 +85,56 @@ Persistent Routes:
 
 	testcases := []testcase{
 		{correctData, true, "10.88.88.2"},
+		{localizedData, true, "10.88.88.2"},
 		{randomData, false, ""},
 		{noRoute, false, ""},
 		{badRoute1, false, ""},
 		{badRoute2, false, ""},
 	}
 
-	test(t, testcases, parseWindowsRoutePrint)
+	test(t, testcases, parseWindowsGatewayIP)
+
+	interfaceTestCases := []testcase{
+		{correctData, true, "10.88.88.149"},
+		{localizedData, true, "10.88.88.149"},
+		{randomData, false, ""},
+		{noRoute, false, ""},
+		{badRoute1, false, ""},
+		{badRoute2, true, "10.88.88.149"},
+	}
+
+	test(t, interfaceTestCases, parseWindowsInterfaceIP)
 }
 
-func TestParseLinuxIPRoutePrint(t *testing.T) {
-	correctData := []byte(`
-default via 192.168.178.1 dev wlp3s0  metric 303
-192.168.178.0/24 dev wlp3s0  proto kernel  scope link  src 192.168.178.76  metric 303
-`)
-	randomData := []byte(`
-test
-Lorem ipsum dolor sit amet, consectetur adipiscing elit,
-sed do eiusmod tempor incididunt ut labore et dolore magna
-aliqua. Ut enim ad minim veniam, quis nostrud exercitation
+func TestParseLinux(t *testing.T) {
+	correctData := []byte(`Iface	Destination	Gateway 	Flags	RefCnt	Use	Metric	Mask		MTU	Window	IRTT                                                       
+wlp4s0	0000FEA9	00000000	0001	0	0	1000	0000FFFF	0	0	0                                                                          
+docker0	000011AC	00000000	0001	0	0	0	0000FFFF	0	0	0                                                                            
+docker_gwbridge	000012AC	00000000	0001	0	0	0	0000FFFF	0	0	0                                                                    
+wlp4s0	0008A8C0	00000000	0001	0	0	600	00FFFFFF	0	0	0                                                                           
+wlp4s0	00000000	0108A8C0	0003	0	0	600	00000000	0	0	0                                                                           
 `)
 	noRoute := []byte(`
-192.168.178.0/24 dev wlp3s0  proto kernel  scope link  src 192.168.178.76  metric 303
-`)
-	badRoute := []byte(`
-default via foo dev wlp3s0  metric 303
-192.168.178.0/24 dev wlp3s0  proto kernel  scope link  src 192.168.178.76  metric 303
+Iface   Destination     Gateway         Flags   RefCnt  Use     Metric  Mask            MTU     Window  IRTT                                                       
 `)
 
 	testcases := []testcase{
-		{correctData, true, "192.168.178.1"},
-		{randomData, false, ""},
+		{correctData, true, "192.168.8.1"},
 		{noRoute, false, ""},
-		{badRoute, false, ""},
 	}
 
-	test(t, testcases, parseLinuxIPRoute)
-}
+	test(t, testcases, parseLinuxGatewayIP)
 
-func TestParseLinuxRoutePrint(t *testing.T) {
-	correctData := []byte(`
-Kernel IP routing table
-Destination     Gateway         Genmask         Flags Metric Ref    Use Iface
-0.0.0.0         192.168.1.1     0.0.0.0         UG    0      0        0 eth0
-`)
-	randomData := []byte(`
-test
-Lorem ipsum dolor sit amet, consectetur adipiscing elit,
-sed do eiusmod tempor incididunt ut labore et dolore magna
-aliqua. Ut enim ad minim veniam, quis nostrud exercitation
-`)
-	noRoute := []byte(`
-Kernel IP routing table
-Destination     Gateway         Genmask         Flags Metric Ref    Use Iface
-`)
-	badRoute := []byte(`
-Kernel IP routing table
-Destination     Gateway         Genmask         Flags Metric Ref    Use Iface
-0.0.0.0         foo     0.0.0.0         UG    0      0        0 eth0
-`)
+	// ifData := []byte(`Iface	Destination	Gateway 	Flags	RefCnt	Use	Metric	Mask		MTU	Window	IRTT                                                       
+    // eth0	00000000	00000000	0001	0	0	1000	0000FFFF	0	0	0                                                                          
+    // `)
+	// interfaceTestCases := []testcase{
+	// 	{ifData, true, "192.168.8.238"},
+	// 	{noRoute, false, ""},
+	// }
 
-	testcases := []testcase{
-		{correctData, true, "192.168.1.1"},
-		{randomData, false, ""},
-		{noRoute, false, ""},
-		{badRoute, false, ""},
-	}
-
-	test(t, testcases, parseLinuxRoute)
-}
-
-func TestParseDarwinRouteGet(t *testing.T) {
-	correctData := []byte(`
-   route to: 0.0.0.0
-destination: default
-       mask: default
-    gateway: 172.16.32.1
-  interface: en0
-      flags: <UP,GATEWAY,DONE,STATIC,PRCLONING>
- recvpipe  sendpipe  ssthresh  rtt,msec    rttvar  hopcount      mtu     expire
-       0         0         0         0         0         0      1500         0
-`)
-	randomData := []byte(`
-test
-Lorem ipsum dolor sit amet, consectetur adipiscing elit,
-sed do eiusmod tempor incididunt ut labore et dolore magna
-aliqua. Ut enim ad minim veniam, quis nostrud exercitation
-`)
-	noRoute := []byte(`
-   route to: 0.0.0.0
-destination: default
-       mask: default
-`)
-	badRoute := []byte(`
-   route to: 0.0.0.0
-destination: default
-       mask: default
-    gateway: foo
-  interface: en0
-      flags: <UP,GATEWAY,DONE,STATIC,PRCLONING>
- recvpipe  sendpipe  ssthresh  rtt,msec    rttvar  hopcount      mtu     expire
-       0         0         0         0         0         0      1500         0
-`)
-
-	testcases := []testcase{
-		{correctData, true, "172.16.32.1"},
-		{randomData, false, ""},
-		{noRoute, false, ""},
-		{badRoute, false, ""},
-	}
-
-	test(t, testcases, parseDarwinRouteGet)
+	// to run interface test in your local computer, change eth0 with your default interface name, and change the expected IP to be your default IP
+	// test(t, interfaceTestCases, parseLinuxInterfaceIP)
 }
 
 func TestParseBSDSolarisNetstat(t *testing.T) {
@@ -228,6 +202,49 @@ default            foo                UGS         em0
 	test(t, testcases, parseBSDSolarisNetstat)
 }
 
+func TestParseDarwinRouteGet(t *testing.T) {
+	correctData := []byte(`
+   route to: 0.0.0.0
+destination: default
+       mask: default
+    gateway: 172.16.32.1
+  interface: en0
+      flags: <UP,GATEWAY,DONE,STATIC,PRCLONING>
+ recvpipe  sendpipe  ssthresh  rtt,msec    rttvar  hopcount      mtu     expire
+       0         0         0         0         0         0      1500         0
+`)
+	randomData := []byte(`
+test
+Lorem ipsum dolor sit amet, consectetur adipiscing elit,
+sed do eiusmod tempor incididunt ut labore et dolore magna
+aliqua. Ut enim ad minim veniam, quis nostrud exercitation
+`)
+	noRoute := []byte(`
+   route to: 0.0.0.0
+destination: default
+       mask: default
+`)
+	badRoute := []byte(`
+   route to: 0.0.0.0
+destination: default
+       mask: default
+    gateway: foo
+  interface: en0
+      flags: <UP,GATEWAY,DONE,STATIC,PRCLONING>
+ recvpipe  sendpipe  ssthresh  rtt,msec    rttvar  hopcount      mtu     expire
+       0         0         0         0         0         0      1500         0
+`)
+
+	testcases := []testcase{
+		{correctData, true, "172.16.32.1"},
+		{randomData, false, ""},
+		{noRoute, false, ""},
+		{badRoute, false, ""},
+	}
+
+	test(t, testcases, parseDarwinRouteGet)
+}
+
 func test(t *testing.T, testcases []testcase, fn func([]byte) (net.IP, error)) {
 	for i, tc := range testcases {
 		net, err := fn(tc.output)
